| Home | Libraries | People | FAQ | More

## Overview

This section contains internal utilities used by the library's implementation along with tools used in development and testing. These tools have limitied documentation, but now have quite stable interfaces and may also be useful outside Boost.Math.

There is no doubt that these components can be improved, but they are also largely incidental to the main purpose of this library.

These tools are designed to "just get the job done", and receive minimal documentation here, in the hopes that they will help stimulate further submissions to this library.